@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::WithJunctions;
 {
-  $List::Objects::WithUtils::Role::WithJunctions::VERSION = '0.002003';
+  $List::Objects::WithUtils::Role::WithJunctions::VERSION = '0.002004';
 }
 use strictures 1;
 use Role::Tiny;
@@ -29,6 +29,7 @@ List::Objects::WithUtils::Role::WithJunctions - Arrays with junctions
 
 =head1 SYNOPSIS
 
+  ## Via List::Objects::WithUtils::Array ->
   use List::Objects::WithUtils 'array';
 
   my $array = array(qw/ a b c /);
@@ -41,6 +42,11 @@ List::Objects::WithUtils::Role::WithJunctions - Arrays with junctions
     ...
   }
 
+  ## As a Role ->
+  use Role::Tiny::With;
+  with 'List::Objects::WithUtils::Role::Array',
+       'List::Objects::WithUtils::Role::WithJunctions';
+
 =head1 DESCRIPTION
 
 Used by L<List::Objects::WithUtils::Array> to provide access to
